@@ -52,41 +52,6 @@ arex_job_states = [
     "CANCELLING"
 ]
 
-# data staging states
-data_staging_states = [
-    "NEW",
-    "CHECK_CACHE",
-    "RESOLVE",
-    "QUERY_REPLICA",
-    "PRE_CLEAN",
-    "STAGE_PREPARE",
-    "TRANSFER_WAIT",
-    "TRANSFER",
-    "RELEASE_REQUEST",
-    "REGISTER_REPLICA",
-    "PROCESS_CACHE",
-    "CHECKING_CACHE",
-    "CACHE_WAIT",
-    "CACHE_CHECKED",
-    "RESOLVING",
-    "RESOLVED",
-    "QUERYING_REPLICA",
-    "REPLICA_QUERIED",
-    "PRE_CLEANING",
-    "PRE_CLEANED",
-    "STAGING_PREPARING",
-    "STAGING_PREPARING_WAIT",
-    "STAGED_PREPARED",
-    "TRANSFERRING",
-    "TRANSFERRING_CANCEL",
-    "TRANSFERRED",
-    "RELEASING_REQUEST",
-    "REQUEST_RELEASED",
-    "REGISTERING_REPLICA",
-    "REPLICA_REGISTERED",
-    "PROCESSING_CACHE",
-    "CACHE_PROCESSED"
-    ]
 
 # where to get data staging info
 data_staging_info = "dtrstate.log"
@@ -490,6 +455,89 @@ def getSessionFree():
         runGmetric('ARC_SESSION_FREE_TOTAL', totalfree, 'GB', 'float')
 
 
+def getJobsINLRMS():
+    '''
+    Checks jobs in the 'processing' subdir of the
+    control dir. This will only work on ARC1 clusters.
+    '''
+
+    if 'controldir' in conf['grid-manager']:
+        controldir = conf['grid-manager']['controldir'][0]
+    else:
+        logging.error("No control dir found in configuration")
+        return
+    processing_dir = controldir + "/processing"
+
+
+    entries = []
+    try:
+        entries = [stat_file for stat_file in os.listdir(processing_dir) if '.status' in stat_file]
+    except OSError:
+        e = sys.exc_info()[1]
+        logging.error("Error listing dir %s: %s", processing_dir, str(e))
+  
+
+    '''extract the number of cores for this running job from the job.<jobid>.grami file'''
+    cores={}
+    for status_file in entries:
+        ''' open the status file and check that the job is actually processing (INLRMS), if not go to next job '''
+        try:
+            with open(controldir + '/processing/' + status_file) as f:state=f.read()
+            if 'INLRMS' not in state:
+                continue
+        except IOError:
+            e = sys.exc_info()[1]
+            logging.error('Error opening file %s: %s', status_file, str(e))
+
+
+
+        jobid = status_file[4:-7]
+        gramifN = controldir +'/job.'+jobid+'.grami'
+
+        try:
+            f=open(gramifN)
+        except IOError:
+            e = sys.exc_info()[1]
+            logging.error("Cannot open file %s: %s. Skipping.", gramifN, str(e))
+            continue
+
+        ''' extract info about cores from grami file '''
+        for line in f:
+            if 'coreCount' in line:
+                parts = line.split('&')
+                for part in parts:
+                    if 'coreCount' in part:
+                        try:
+                            cN = int(part.split('=')[-1])
+                        except ValueError:
+                            e = sys.exc_info()[1]
+                            logging.error("Problems finding number of cores %s. Skipping",str(e))
+                            continue
+                        if cN in cores:
+                            cores[cN] += 1
+                        else:
+                            cores[cN] = 1
+        f.close()                    
+
+
+    ''' publish info on number of jobs using certain number of cores'''
+    for corenum,jobs in cores.iteritems():
+        logging.info("%i job(s) INLRMS use %i core(s)",jobs, corenum)
+        corestr = 'ARC_JOBS_INLRMS_' + str(corenum) + 'CORES'
+        runGmetric(corestr, jobs, 'jobs', 'int32')
+        
+
+
+    ''' get total amount of cores for all jobs '''
+    totalcores = 0        
+    for corenum, jobs in cores.iteritems():
+        totalcores += jobs*corenum
+    
+    if totalcores:
+        logging.info("Total number of cores INLRMS %s",totalcores)
+        runGmetric('ARC_JOBS_INLRMS_TOTALCORES', totalcores, 'cores', 'int32')
+       
+
 def getProcessingJobs():
     '''
     Count the number of jobs in the 'processing' subdir of the
@@ -506,6 +554,7 @@ def getProcessingJobs():
 
     processing_dir = controldir + "/processing"
 
+    entries = []
     try:
         entries = os.listdir(processing_dir)
     except OSError:
@@ -514,10 +563,68 @@ def getProcessingJobs():
         return
     processing += len(entries)
 
+    ''' display processing info '''
     logging.info("%i jobs in processing", processing)
     runGmetric('ARC_JOBS_PROCESSING', processing, 'jobs', 'int32')
 
 
+    '''extract the number of cores for this running job from the job.<jobid>.grami file'''
+    cores={}
+    for status_file in entries:
+        if status_file.endswith('.status'):
+            ''' open the status file and check that the job is actually processing (INLRMS), if not go to next job '''
+            try:
+                with open(controldir + '/processing/' + status_file) as f:state=f.read()
+                if 'INLRMS' not in state:
+                    print 'not counting ', state, status_file
+                    continue
+                else:
+                    print state
+            except IOError:
+                e = sys.exc_info()[1]
+                logging.error('Error opening file %s: %s', status_file, str(e))
+            
+            jobid = status_file[4:-7]
+            gramifN = controldir +'/job.'+jobid+'.grami'
+            
+        print status_file , '\n'
+        try:
+            f=open(gramifN)
+        except IOError:
+            e = sys.exc_info()[1]
+            logging.error("Cannot open file %s: %s. Skipping.", gramifN, str(e))
+            continue
+
+
+        for line in f:
+            if 'coreCount' in line:
+                parts = line.split('&')
+                for part in parts:
+                    if 'coreCount' in part:
+                        try:
+                            cN = int(part.split('=')[-1])
+                        except ValueError:
+                            e = sys.exc_info()[1]
+                            logging.error("Problems finding number of cores %s. Skipping",str(e))
+                            continue
+                        if cN in cores:
+                            cores[cN] += 1
+                        else:
+                            cores[cN] = 1
+        f.close()                    
+
+
+    for corenum,jobs in cores.iteritems():
+        logging.info("%i job(s) use %i core(s)",jobs, corenum)
+        corestr = 'ARC_JOBS_PROCESSING_' + str(corenum) + 'CORES'
+        runGmetric(corestr, jobs, 'jobs', 'int32')
+        
+
+
+    
+
+    
+
 def getFailedJobs():
     '''
     Look into the grid manager jobs log file to extract
@@ -632,6 +739,10 @@ def run(conffile, pidfile, logfile):
                 # processing jobs
                 getProcessingJobs()
 
+            if 'getJobsINLRMS' in metrics or 'all' in metrics:
+                # processing jobs
+                getJobsINLRMS()
+
             if 'failedjobs' in metrics or 'all' in metrics:
                 # number of failed jobs among last 100
                 getFailedJobs()
